%global libnbt_ver 0.6.1
%global quazip_ver 3

%ifarch %arm
%bcond_without clang
%else
%bcond_with clang
%endif

%if %{with clang}
# https://bugzilla.redhat.com/show_bug.cgi?id=2023666
%global build_ldflags %build_ldflags -Wl,--build-id=sha1
%endif

Name:           multimc
Version:        0.6.13
Release:        %mkrel 9
Summary:        MultiMC is a free, open source launcher for Minecraft
Group:          Games/Simulation
License:        ASL 2.0
URL:            https://multimc.org
Source0:        https://github.com/MultiMC/MultiMC5/archive/%{version}/multimc-%{version}.tar.gz
Source1:        https://github.com/MultiMC/libnbtplusplus/archive/multimc-%{libnbt_ver}/libnbtplusplus-multimc-%{libnbt_ver}.tar.gz
Source2:        https://github.com/MultiMC/quazip/archive/multimc-%{quazip_ver}/quazip-multimc-%{quazip_ver}.tar.gz
Patch0:         multimc-0.6.13-dead_code.patch
Patch1:         0001-Update-Java-version-to-7+.patch
Patch2:         multimc-cmake-4.0.patch

BuildRequires:  cmake
BuildRequires:  java-devel
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(zlib)
%if %{with clang}
# https://github.com/MultiMC/Launcher/issues/2895
BuildRequires:  clang
%endif
Recommends:     jre

%description
MultiMC is a free, open source launcher for Minecraft. It allows you to have
multiple, cleanly separated instances of Minecraft (each with their own mods,
resource packs, saves, etc) and helps you manage them and their associated
options with a simple and powerful interface.

%prep
%setup -q -n MultiMC5-%{version} -a 1 -a 2
rmdir libraries/libnbtplusplus
mv libnbtplusplus-multimc-%{libnbt_ver} libraries/libnbtplusplus
rmdir libraries/quazip
mv quazip-multimc-%{quazip_ver} libraries/quazip
%autopatch -p1

sed -i 's|-Wall -pedantic -Werror|-Wall -pedantic|' CMakeLists.txt

%build
mkdir build
%cmake -DMultiMC_LAYOUT=lin-system \
%if %{with clang}
       -DCMAKE_C_COMPILER=clang \
       -DCMAKE_CXX_COMPILER=clang++ \
%endif

%cmake_build

%install
%cmake_install
install -D launcher/package/linux/multimc.desktop \
  %{buildroot}%{_datadir}/applications/%{name}.desktop
install -D launcher/package/ubuntu/multimc/opt/multimc/icon.svg \
  %{buildroot}%{_iconsdir}/hicolor/scalable/apps/%{name}.svg

%files
%doc README.md
%{_bindir}/multimc
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/scalable/apps/%{name}.svg
%{_datadir}/multimc/
%{_libdir}/libMultiMC*.so


%changelog
* Fri Jul 11 2025 daviddavid <daviddavid> 0.6.13-9.mga10
+ Revision: 2252886
- fix build with cmake 4.0
+ umeabot <umeabot>
- Mageia 10 Mass Rebuild

* Thu Oct 17 2024 daviddavid <daviddavid> 0.6.13-8.mga10
+ Revision: 2107689
- fix build with java 21

* Mon Jan 02 2023 daviddavid <daviddavid> 0.6.13-7.mga9
+ Revision: 1929137
- add upstream patch to fix build with java >= 7
- package a desktop svg icon
- split out all Qt5 build dependencies

* Mon Apr 04 2022 umeabot <umeabot> 0.6.13-6.mga9
+ Revision: 1842977
- Mageia 9 Mass Rebuild

* Mon Feb 21 2022 pterjan <pterjan> 0.6.13-5.mga9
+ Revision: 1782221
- Fix clang build

* Sun Feb 20 2022 pterjan <pterjan> 0.6.13-4.mga9
+ Revision: 1781957
- Add a patch to delete set but unused variables, this causes a failure with -Werror when using clang

* Sun Feb 20 2022 pterjan <pterjan> 0.6.13-3.mga9
+ Revision: 1781794
- Fix the attempt to build with clang on arm

* Sun Feb 20 2022 pterjan <pterjan> 0.6.13-2.mga9
+ Revision: 1781747
- Build with clang on armv7hl

* Sun Sep 12 2021 buchan <buchan> 0.6.13-1.mga9
+ Revision: 1745372
- imported package multimc

